Contributors Guide
==================

These pages target people who are interested in contributing directly to the Gateway Provisioners Project.

.. admonition:: Use cases

    - *As a contributor, I want to learn more about kernel management within the Jupyter ecosystem.*
    - *As a contributor, I want to make Gateway Provisioners more stable for my organization and the community as a whole.*

.. note::
   As a *contributor*, we encourage you to be familiar with all of the guides (`Users <../users/index.html>`_, `Developers <../developers/index.html>`_, `Operators <../operators/index.html>`_) to best support Gateway Provisioners.  This guide provides an overview of Gateway Provisioners along with instructions on how to get set up.


.. toctree::
   :maxdepth: 1
   :name: contributors

   contrib
   devinstall
   system-architecture
   sequence-diagrams
   related-resources
